aboutsummaryrefslogtreecommitdiff
path: root/include/armnn/backends/profiling/IBackendProfilingContext.hpp
diff options
context:
space:
mode:
authorCathal Corbett <cathal.corbett@arm.com>2022-02-25 15:33:28 +0000
committerCathal Corbett <cathal.corbett@arm.com>2022-03-01 11:44:14 +0000
commit5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab (patch)
tree23a3a0d5ca5143924277f34c98d36cf7b99430a7 /include/armnn/backends/profiling/IBackendProfilingContext.hpp
parent1fc448ad2455ad31b96a3891f847125a3295d75a (diff)
downloadarmnn-5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab.tar.gz
IVGCVSW-6704 Change the namespace from armnn::profiling to arm::pipe
* Updated ABI version to 29 due to being the first ABI break in 22.05 !android-nn-driver:7226 Signed-off-by: Cathal Corbett <cathal.corbett@arm.com> Change-Id: I9c50007dcd5b5e792757e7bd1213606df5ffec36
Diffstat (limited to 'include/armnn/backends/profiling/IBackendProfilingContext.hpp')
-rw-r--r--include/armnn/backends/profiling/IBackendProfilingContext.hpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/include/armnn/backends/profiling/IBackendProfilingContext.hpp b/include/armnn/backends/profiling/IBackendProfilingContext.hpp
index 77959e959b..2e3df48227 100644
--- a/include/armnn/backends/profiling/IBackendProfilingContext.hpp
+++ b/include/armnn/backends/profiling/IBackendProfilingContext.hpp
@@ -8,9 +8,9 @@
#include <armnn/IRuntime.hpp>
#include <vector>
-namespace armnn
+namespace arm
{
-namespace profiling
+namespace pipe
{
class IBackendProfilingContext
@@ -19,12 +19,13 @@ public:
virtual ~IBackendProfilingContext()
{}
virtual uint16_t RegisterCounters(uint16_t currentMaxGlobalCounterID) = 0;
- virtual Optional<std::string> ActivateCounters(uint32_t capturePeriod, const std::vector<uint16_t>& counterIds) = 0;
+ virtual armnn::Optional<std::string> ActivateCounters(uint32_t capturePeriod, const std::vector<uint16_t>&
+ counterIds) = 0;
virtual std::vector<Timestamp> ReportCounterValues() = 0;
virtual bool EnableProfiling(bool flag) = 0;
virtual bool EnableTimelineReporting(bool flag) = 0;
};
using IBackendProfilingContextUniquePtr = std::unique_ptr<IBackendProfilingContext>;
-} // namespace profiling
-} // namespace armnn \ No newline at end of file
+} // namespace pipe
+} // namespace arm \ No newline at end of file